Documentation
¶
Overview ¶
Package sshkey implements the sshkey module in the agent
Index ¶
Constants ¶
const ( KeyTypePrivate = "private" KeyTypePublic = "public" KeyTypeAuthorizedKeys = "authorizedkeys" )
Constants used in KeyInfo.Type
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Elements ¶
type Elements struct {
Keys []KeyInfo `json:"keys"`
}
Elements is the type that contains the results of a module invocation
type KeyInfo ¶
type KeyInfo struct {
FingerprintMD5 string `json:"fingerprint_md5"` // MD5 fingerprint
FingerprintSHA256 string `json:"fingerprint_sha256"` // SHA256 fingerprint
Path string `json:"path"` // Path to file
Encrypted bool `json:"encrypted"` // True if private key is encrypted
Type string `json:"type"` // Type of file (e.g., private, public)
}
KeyInfo describes information about a key that has been identified
Click to show internal directories.
Click to hide internal directories.